@@ -5,13 +5,13 @@ import (
 
 	"github.com/asdine/storm/v3"
 
-	fbErrors "github.com/filebrowser/filebrowser/v2/errors"
+	fberrors "github.com/filebrowser/filebrowser/v2/errors"
 )
 
 func get(db *storm.DB, name string, to interface{}) error {
 	err := db.Get("config", name, to)
 	if errors.Is(err, storm.ErrNotFound) {
-		return fbErrors.ErrNotExist
+		return fberrors.ErrNotExist
 	}
 
 	return err
