@@ -6,17 +6,17 @@ import (
 
 	"golang.org/x/crypto/bcrypt"
 
-	fbErrors "github.com/filebrowser/filebrowser/v2/errors"
+	fberrors "github.com/filebrowser/filebrowser/v2/errors"
 )
 
 // ValidateAndHashPwd validates and hashes a password.
 func ValidateAndHashPwd(password string, minimumLength uint) (string, error) {
 	if uint(len(password)) < minimumLength {
-		return "", fbErrors.ErrShortPassword{MinimumLength: minimumLength}
+		return "", fberrors.ErrShortPassword{MinimumLength: minimumLength}
 	}
 
 	if _, ok := commonPasswords[password]; ok {
-		return "", fbErrors.ErrEasyPassword
+		return "", fberrors.ErrEasyPassword
 	}
 
 	return HashPwd(password)
